'use strict'

const qs = require('qs')

/**
 * Helper Class.
 * @class
 * @name Helper
 */
function Helper () {}

/**
 * Create QueryString for Including Associations.
 * @param {string[]} include - An Array of include associations
 * @return {string} Query String
 */
Helper.prototype.includeAssociations = (include) => {
  return qs.stringify({
    include: include
  }, {
    encode: false,
    indices: false,
    arrayFormat: 'brackets'
  })
}

/**
 * Create QueryString for Query Parameters.
 * @param {Object} params - Query parameters
 * @return {string} Query String
 */
Helper.prototype.queryParameters = (params) => {
  return qs.stringify(params, {
    encode: false,
    indices: false,
    arrayFormat: 'repeat'
  })
}

Helper.prototype.bufferPdf = (data) => {
  return new Buffer.from(data, 'binary')
}

/**
 * Export helper functions.
 * @module Helper
 */
module.exports = Helper
